import 'package:fl_chart/fl_chart.dart';
import 'package:flutter/material.dart';
import 'package:sci_mobile_components/src/models/vital_sign.dart';

class SCIHWChart extends StatelessWidget {
  final List<VitalSignData> weight;
  final List<VitalSignData> height;

  const SCIHWChart({required this.weight, required this.height});

  @override
  Widget build(BuildContext context) {
    return Column(
      children: <Widget>[
        Container(
          width: double.infinity,
          height: 200.0,
          child: LineChart(
            LineChartData(
              gridData: FlGridData(horizontalInterval: 20.0),
              lineTouchData: LineTouchData(enabled: false),
              axisTitleData: FlAxisTitleData(
                show: true,
                topTitle: AxisTitle(
                  showTitle: true,
                  titleText: 'Berat & Tinggi Badan',
                  textStyle: Theme.of(context).textTheme.headline5,
                ),
              ),
              titlesData: FlTitlesData(
                bottomTitles: SideTitles(showTitles: false),
                leftTitles: SideTitles(
                  showTitles: true,
                  interval: 15.0,
                  margin: 10.0,
                  getTextStyles: (axis) => Theme.of(context)
                      .textTheme
                      .caption!
                      .copyWith(fontWeight: FontWeight.bold),
                  getTitles: (i) => '${i.toInt()}',
                ),
              ),
              borderData: FlBorderData(
                show: true,
                border: Border.all(
                  color: Colors.blue,
                  width: 3.0,
                ),
              ),
              minY: 40,
              maxY: 200,
              lineBarsData: [
                /// Height
                LineChartBarData(
                  colors: [Colors.redAccent],
                  show: true,
                  barWidth: 2.0,
                  spots: height
                      .map(
                        (s) => FlSpot(
                          s.createdDate.day.toDouble() - 1,
                          double.parse(s.value),
                        ),
                      )
                      .toList(),
                ),

                /// Weight
                LineChartBarData(
                  colors: [Colors.blue],
                  show: true,
                  barWidth: 2.0,
                  spots: weight
                      .map(
                        (d) => FlSpot(
                          d.createdDate.day.toDouble() - 1,
                          double.parse(d.value),
                        ),
                      )
                      .toList(),
                ),
              ],
            ),
          ),
        ),
        SizedBox(height: 10.0),

        /// Legend
        Row(
          mainAxisAlignment: MainAxisAlignment.center,
          children: <Widget>[
            Spacer(flex: 3),
            Text(
              'Tinggi Badan',
              style: Theme.of(context).textTheme.bodyText1,
            ),
            Spacer(),
            Container(
              height: 10.0,
              width: 10.0,
              color: Colors.redAccent,
            ),
            Spacer(),
            Text(
              'Berat Badan',
              style: Theme.of(context).textTheme.bodyText1,
            ),
            Spacer(),
            Container(
              height: 10.0,
              width: 10.0,
              color: Colors.blue,
            ),
            Spacer(flex: 3)
          ],
        )
      ],
    );
  }
}
