import 'package:fl_chart/fl_chart.dart';
import 'package:flutter/material.dart';
import 'package:sci_mobile_components/src/models/vital_sign.dart';

class SCIRespChart extends StatelessWidget {
  final List<VitalSignData> rate;
  final int ageInDay;

  SCIRespChart({
    required this.rate,
    required this.ageInDay,
  });

  double batasAtas(int ageInDay) {
    if (ageInDay == 0) {
      return 80;
    } else if (ageInDay <= 30 && ageInDay > 0) {
      return 80.0;
    } else if (ageInDay <= 122 && ageInDay > 30) {
      return 70.0;
    } else if (ageInDay <= 366 && ageInDay > 122) {
      return 60.0;
    } else if (ageInDay <= 1830 && ageInDay > 366) {
      return 50.0;
    } else if (ageInDay <= 4381 && ageInDay > 1830) {
      return 30.0;
    } else if (ageInDay <= 6589 && ageInDay > 4381) {
      return 25.0;
    } else {
      return 25.0;
    }
  }

  double batasBawah(int ageInDay) {
    if (ageInDay == 0) {
      return 20.0;
    } else if (ageInDay <= 30 && ageInDay > 0) {
      return 15.0;
    } else if (ageInDay <= 122 && ageInDay > 30) {
      return 15.0;
    } else if (ageInDay <= 366 && ageInDay > 122) {
      return 15.0;
    } else if (ageInDay <= 1830 && ageInDay > 366) {
      return 10.0;
    } else if (ageInDay <= 4381 && ageInDay > 1830) {
      return 10.0;
    } else if (ageInDay <= 6589 && ageInDay > 4381) {
      return 9.0;
    } else {
      return 9.0;
    }
  }

  @override
  Widget build(BuildContext context) {
    final double maxX =
        (rate.first.recordDate.millisecondsSinceEpoch / 100000).toDouble();
    final double minX =
        (rate.last.recordDate.millisecondsSinceEpoch / 100000).toDouble();

    return Column(
      children: <Widget>[
        Container(
          width: double.infinity,
          height: 200.0,
          child: LineChart(
            LineChartData(
              gridData: FlGridData(horizontalInterval: 10.0),
              lineTouchData: LineTouchData(enabled: false),
              axisTitleData: FlAxisTitleData(
                show: true,
                topTitle: AxisTitle(
                  showTitle: true,
                  titleText: 'Respiratory Rate',
                  textStyle: Theme.of(context).textTheme.headline5,
                ),
              ),
              titlesData: FlTitlesData(
                bottomTitles: SideTitles(showTitles: false),
                leftTitles: SideTitles(
                  showTitles: true,
                  interval: 10.0,
                  margin: 10.0,
                  getTextStyles: (axis) => Theme.of(context)
                      .textTheme
                      .caption!
                      .copyWith(fontWeight: FontWeight.bold),
                  getTitles: (i) => '${i.toInt()}',
                ),
              ),
              borderData: FlBorderData(
                show: true,
                border: Border.all(
                  color: Colors.blue,
                  width: 3.0,
                ),
              ),
              minX: minX,
              maxX: maxX,
              minY: 0,
              maxY: 100,
              lineBarsData: [
                /// Batas atas
                LineChartBarData(
                  colors: [Colors.yellow.withOpacity(0.3)],
                  show: true,
                  spots: [
                    FlSpot(minX, batasAtas(ageInDay)),
                    FlSpot(maxX, batasAtas(ageInDay)),
                  ],
                  aboveBarData: BarAreaData(
                    show: true,
                    colors: [Colors.yellow.withOpacity(0.3)],
                  ),
                  dotData: FlDotData(
                    show: false,
                  ),
                ),

                /// Batas bawah
                LineChartBarData(
                  colors: [Colors.yellow.withOpacity(0.3)],
                  show: true,
                  spots: [
                    FlSpot(minX, batasBawah(ageInDay)),
                    FlSpot(maxX, batasBawah(ageInDay)),
                  ],
                  belowBarData: BarAreaData(
                    show: true,
                    colors: [Colors.yellow.withOpacity(0.3)],
                  ),
                  dotData: FlDotData(
                    show: false,
                  ),
                ),

                /// rate
                LineChartBarData(
                  colors: [Colors.redAccent],
                  show: true,
                  barWidth: 2.0,
                  spots: rate
                      .map(
                        (s) => FlSpot(
                          (s.recordDate.millisecondsSinceEpoch / 100000)
                              .toDouble(),
                          double.parse(s.value),
                        ),
                      )
                      .toList(),
                ),
              ],
            ),
          ),
        ),
        SizedBox(height: 10.0),

        /// Legend
        Row(
          mainAxisAlignment: MainAxisAlignment.center,
          children: <Widget>[
            Spacer(flex: 3),
            Text(
              'Heart Rate',
              style: Theme.of(context).textTheme.bodyText1,
            ),
            Spacer(),
            Container(
              height: 10.0,
              width: 10.0,
              color: Colors.redAccent,
            ),
            Spacer(flex: 3)
          ],
        )
      ],
    );
  }
}
