import 'package:fl_chart/fl_chart.dart';
import 'package:flutter/material.dart';
import 'package:sci_mobile_components/src/models/vital_sign.dart';

class SCITempChart extends StatelessWidget {
  final List<VitalSignData> temperature;

  SCITempChart({required this.temperature});

  @override
  Widget build(BuildContext context) {
    return Column(
      children: <Widget>[
        Container(
          width: double.infinity,
          height: 200.0,
          child: LineChart(
            LineChartData(
              minX:
                  (temperature.first.recordDate.millisecondsSinceEpoch / 100000)
                      .toDouble(),
              maxX:
                  (temperature.last.recordDate.millisecondsSinceEpoch / 100000)
                      .toDouble(),
              minY: 0,
              maxY: 100,
              gridData: FlGridData(horizontalInterval: 10.0),
              lineTouchData: LineTouchData(enabled: false),
              axisTitleData: FlAxisTitleData(
                show: true,
                topTitle: AxisTitle(
                  showTitle: true,
                  titleText: 'Temperature',
                  textStyle: Theme.of(context).textTheme.headline5,
                ),
              ),
              titlesData: FlTitlesData(
                bottomTitles: SideTitles(showTitles: false),
                leftTitles: SideTitles(
                  showTitles: true,
                  interval: 10.0,
                  margin: 10.0,
                  getTextStyles: (axis) => Theme.of(context)
                      .textTheme
                      .caption!
                      .copyWith(fontWeight: FontWeight.bold),
                  getTitles: (i) => '${i.toInt()}',
                ),
              ),
              borderData: FlBorderData(
                show: true,
                border: Border.all(
                  color: Colors.blue,
                  width: 3.0,
                ),
              ),
              lineBarsData: [
                /// Temperature
                LineChartBarData(
                  colors: [Colors.redAccent],
                  show: true,
                  barWidth: 2.0,
                  spots: temperature.map((s) {
                    return FlSpot(
                      (s.recordDate.millisecondsSinceEpoch / 100000).toDouble(),
                      double.parse(s.value),
                    );
                  }).toList(),
                ),
              ],
            ),
          ),
        ),
        SizedBox(height: 10.0),

        /// Legend
        Row(
          mainAxisAlignment: MainAxisAlignment.center,
          children: <Widget>[
            Spacer(flex: 3),
            Text(
              'Temperature',
              style: Theme.of(context).textTheme.bodyText1,
            ),
            Spacer(),
            Container(
              height: 10.0,
              width: 10.0,
              color: Colors.redAccent,
            ),
            Spacer(flex: 3)
          ],
        )
      ],
    );
  }
}
